@@ -12,9 +12,9 @@ Planet = PlanetStruct('Io')
 """ Bulk planetary settings """
 Planet.Do.NO_H2O = True
 Planet.Bulk.qSurf_Wm2 = 140e-3
-# Planet.Bulk.qSurf_Wm2 = 2240e-3  # From Lainey et al. (2009): DOI: 10.1038/nature08108
-Planet.Bulk.R_m = 1821.3e3
-Planet.Bulk.M_kg = 8.9319e22
+# Planet.Bulk.qSurf_Wm2 = 2240e-3  # From Lainey et al. (2009): https://doi.org/10.1038/nature08108
+Planet.Bulk.R_m = 1821.49e3  # Value from mean radius in Archinal et al. (2018): https://doi.org/10.1007/s10569-017-9805-5
+Planet.Bulk.M_kg = 8.932e22  # Value from Hussmann et al. (2006): http://dx.doi.org/10.1016/j.icarus.2006.06.005
 Planet.Bulk.Tsurf_K = 110
 Planet.Bulk.Psurf_MPa = 0.0
 Planet.Bulk.Cmeasured = 0.37685  # Value from Anderson et al. (2001): https://doi.org/10.1029/2000JE001367
