@@ -19,9 +19,9 @@ from PlanetProfile.Plotting.MagPlots import GenerateMagPlots, PlotInductOgram, \
     PlotInductOgramPhaseSpace
 from PlanetProfile.Thermodynamics.LayerPropagators import IceLayers, OceanLayers, InnerLayers
 from PlanetProfile.Thermodynamics.Electrical import ElecConduct
-from PlanetProfile.Thermodynamics.Seismic import SeismicCalcs
+from PlanetProfile.Thermodynamics.Seismic import SeismicCalcs, WriteSeismic
 from PlanetProfile.Utilities.defineStructs import Constants, FigureFilesSubstruct, PlanetStruct, ExplorationResults
-from PlanetProfile.Utilities.SetupInit import SetupInit, SetupFilenames
+from PlanetProfile.Utilities.SetupInit import SetupInit, SetupFilenames, SetCMR2strings
 from PlanetProfile.Utilities.SummaryTables import GetLayerMeans, PrintGeneralSummary, PrintLayerSummaryLatex, PrintLayerTableLatex
 
 # Parallel processing
@@ -182,6 +182,8 @@ def PlanetProfile(Planet, Params):
         # Save data after modeling
         if not Params.NO_SAVEFILE:
             WriteProfile(Planet, Params)
+            if Params.CALC_SEISMIC:
+                WriteSeismic(Planet, Params)
     else:
         # Reload previous run
         Planet, Params = ReloadProfile(Planet, Params)
@@ -202,7 +204,12 @@ def PlanetProfile(Planet, Params):
         Planet, Params = MagneticInduction(Planet, Params)
 
         # Plot induced dipole surface strength
-        if ((not Params.SKIP_PLOTS) and Planet.Do.VALID) and \
+        if Planet.Magnetic.Binm_nT is None:
+            log.warning('Tried to GenerateMagPlots, but Magnetic.Binm_nT is None. ' +
+                        'this likely means a reload file was not found with CALC_NEW_INDUCT ' +
+                        'set to False. Try to re-run with CALC_NEW_INDUCT set to True in '
+                        'configPP.py.')
+        elif ((not Params.SKIP_PLOTS) and Planet.Do.VALID) and \
             not (Params.DO_INDUCTOGRAM or Params.DO_EXPLOREOGRAM):
             GenerateMagPlots([Planet], Params)
 
@@ -375,7 +382,8 @@ def WriteProfile(Planet, Params):
         f'R_m = {Planet.Bulk.R_m:.3f}',
         f'M_kg = {Planet.Bulk.M_kg:.5e}',
         f'Cmeasured = {Planet.Bulk.Cmeasured}',
-        f'Cuncertainty = {Planet.Bulk.Cuncertainty}',
+        f'CuncertaintyLower = {Planet.Bulk.CuncertaintyLower}',
+        f'CuncertaintyUpper = {Planet.Bulk.CuncertaintyUpper}',
         f'Psurf_MPa = {Planet.Bulk.Psurf_MPa:.3f}',
         f'Tsurf_K = {Planet.Bulk.Tsurf_K:.3f}',
         f'qSurf_Wm2 = {Planet.qSurf_Wm2:.3e}',
@@ -528,7 +536,7 @@ def ReloadProfile(Planet, Params, fnameOverride=None):
         nSkip = len(os.path.join(Planet.bodyname, f'{Planet.name}Profile_'))
         Planet.saveLabel = fnameOverride[nSkip:-4]
     else:
-        Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params)
+        Planet, Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params)
     log.info(f'Reloading previously saved run from file: {Params.DataFiles.saveFile}')
     log.debug(f'Steps.n settings from PP{Planet.name}.py will be ignored.')
     if not isfile(Params.DataFiles.saveFile):
@@ -554,7 +562,8 @@ def ReloadProfile(Planet, Params, fnameOverride=None):
         Planet.Sil.poreComp = f.readline().split('=')[-1].strip()
         # Get float values from header
         Planet.Ocean.wOcean_ppt, Planet.Sil.wPore_ppt, Planet.Bulk.R_m, Planet.Bulk.M_kg, Planet.Bulk.Cmeasured, \
-        Planet.Bulk.Cuncertainty, Planet.Bulk.Psurf_MPa, Planet.Bulk.Tsurf_K, Planet.qSurf_Wm2, Planet.qCon_Wm2, \
+        Planet.Bulk.CuncertaintyLower, Planet.Bulk.CuncertaintyUpper, Planet.Bulk.Psurf_MPa, Planet.Bulk.Tsurf_K, \
+        Planet.qSurf_Wm2, Planet.qCon_Wm2, \
         Planet.Bulk.Tb_K, Planet.zb_km, Planet.zClath_m, Planet.D_km, Planet.Pb_MPa, Planet.PbI_MPa, \
         Planet.Ocean.deltaP, Planet.Mtot_kg, Planet.CMR2mean, Planet.CMR2less, Planet.CMR2more, Planet.Ocean.QfromMantle_W, \
         Planet.Ocean.rhoMean_kgm3, Planet.Sil.phiRockMax_frac, Planet.Sil.Qrad_Wkg, Planet.Sil.HtidalMean_Wm3, \
@@ -565,7 +574,7 @@ def ReloadProfile(Planet, Params, fnameOverride=None):
         Planet.Sil.sigmaPorousLayerMean_Sm, Planet.Tconv_K, Planet.etaConv_Pas, Planet.RaConvect, Planet.RaConvectIII, Planet.RaConvectV, \
         Planet.RaCrit, Planet.RaCritIII, Planet.RaCritV, Planet.eLid_m, Planet.eLidIII_m, Planet.eLidV_m, \
         Planet.Dconv_m, Planet.DconvIII_m, Planet.DconvV_m, Planet.deltaTBL_m, Planet.deltaTBLIII_m, Planet.deltaTBLV_m \
-            = (float(f.readline().split('=')[-1]) for _ in range(63))
+            = (float(f.readline().split('=')[-1]) for _ in range(64))
         # Note porosity flags
         Planet.Do.POROUS_ICE = bool(strtobool(f.readline().split('=')[-1].strip()))
         Planet.Do.POROUS_ROCK = Planet.Sil.phiRockMax_frac > 0
@@ -593,6 +602,7 @@ def ReloadProfile(Planet, Params, fnameOverride=None):
     Planet.r_m = np.concatenate((Planet.r_m, [0]))
     Planet.z_m = Planet.Bulk.R_m - Planet.r_m
     Planet.phase = Planet.phase.astype(np.int_)
+    Planet = SetCMR2strings(Planet)
 
     # Read in data for core/mantle trade
     Planet.Sil.Rtrade_m, Planet.Core.Rtrade_m, Planet.Sil.rhoTrade_kgm3, \
@@ -602,7 +612,7 @@ def ReloadProfile(Planet, Params, fnameOverride=None):
 
 
 def InitBayes(bodyname, fEnd):
-    """ Load in a specific profile to use as in initial prior in Bayesian analysis. """
+    """ Load in a specific profile to use as an initial prior in Bayesian analysis. """
     Params = configParams
     # Prevent unnecessary slowdowns and disk space usage
     Params.NO_SAVEFILE = True
@@ -641,6 +651,8 @@ def UpdateRun(Planet, Params, changes=None):
     for key, value in changes.items():
         Planet = AssignPlanetVal(Planet, key, value)
 
+    # Reset Do.VALID in case the previous iteration set it to False
+    Planet.Do.VALID = True
     Planet, Params = PlanetProfile(Planet, Params)
     return Planet, Params
 
@@ -669,7 +681,7 @@ def InductOgram(bodyname, Params):
             else:
                 log.warning(f'{expected} does not exist and no default was found at {default}.')
         Planet = importlib.import_module(expected[:-3].replace(os.sep, '.')).Planet
-        DataFiles, FigureFiles = SetupFilenames(Planet, Params)
+        Planet, DataFiles, FigureFiles = SetupFilenames(Planet, Params)
         tMarks = np.empty(0)
         tMarks = np.append(tMarks, time.time())
         settings = {}
@@ -837,7 +849,7 @@ def ReloadInductOgram(bodyname, Params, fNameOverride=None):
             loadname = bodyname
             bodydir = bodyname
         Planet = importlib.import_module(f'{bodydir}.PP{loadname}InductOgram').Planet
-        Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params)
+        Planet, Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params)
         loadFile = Params.DataFiles.inductOgramFile
     else:
         loadFile = fNameOverride
@@ -850,7 +862,7 @@ def ReloadInductOgram(bodyname, Params, fNameOverride=None):
     Induction = InductionResults
     Induction.bodyname = reload['bodyname'][0]
     Induction.yName = reload['yName'][0]
-    Induction.Texc_hr = {key.strip(): value for key, value in zip(reload['Texc_hr_keys'], reload['Texc_hr_values'][0])}
+    Induction.Texc_hr = {key.strip(): value if np.isfinite(value) else None for key, value in zip(reload['Texc_hr_keys'], reload['Texc_hr_values'][0])}
     Induction.Amp = reload['Amp']
     Induction.phase = reload['phase']
     Induction.Bix_nT = reload['Bix_nT']
@@ -869,7 +881,6 @@ def ReloadInductOgram(bodyname, Params, fNameOverride=None):
     Induction.R_m = reload['R_m']
     Induction.rBds_m = reload['rBds_m']
     Induction.sigmaLayers_Sm = reload['sigmaLayers_Sm']
-    Induction.Texc_hr[np.isnan(Induction.Texc_hr)] = None
 
     Induction.SetAxes(Params.Induct.inductOtype)
     Induction.SetComps(Params.Induct.inductOtype)
@@ -1248,7 +1259,7 @@ def ExploreOgram(bodyname, Params):
         Exploration.xName = Params.Explore.xName
         Exploration.yName = Params.Explore.yName
         Exploration.zName = Params.Explore.zName
-        DataFiles, FigureFiles = SetupFilenames(Planet, Params, exploreAppend=f'{Exploration.xName}{Exploration.yName}',
+        Planet, DataFiles, FigureFiles = SetupFilenames(Planet, Params, exploreAppend=f'{Exploration.xName}{Exploration.yName}',
                                                 figExploreAppend=Exploration.zName)
         if bodyname == 'Test':
             Params.Explore.nx = 5
@@ -1455,7 +1466,7 @@ def ReloadExploreOgram(bodyname, Params, fNameOverride=None):
             loadname = bodyname
             bodydir = bodyname
         Planet = importlib.import_module(f'{bodydir}.PP{loadname}Explore').Planet
-        Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params,
+        Planet, Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params,
                                                               exploreAppend=f'{Params.Explore.xName}{Params.Explore.yName}',
                                                               figExploreAppend=f'{Params.Explore.zName}')
         reload = loadmat(Params.DataFiles.exploreOgramFile)
