@@ -241,13 +241,21 @@ def PlotHydrosphereProps(PlanetList, Params):
                 indsIce = np.sort(np.concatenate((indsI, indsIwet, indsII, indsIIund, indsIII, indsIIIund,
                                                   indsV, indsVund, indsVI, indsVIund, indsClath, indsClathWet)))
                 # Plot sound speeds in ocean and ices vs. depth in hydrosphere
-                axv[0].plot(Planet.Seismic.VP_kms[indsLiq], Planet.z_m[indsLiq]/1e3,
+                indsHydro = np.sort(np.concatenate((indsIce, indsLiq)))
+                VPice = Planet.Seismic.VP_kms[indsHydro]
+                VSice = Planet.Seismic.VS_kms[indsHydro]
+                VPliq = VPice + 0
+                # Set non-matching values to nan to avoid gap-spanning lines in plots
+                VPliq[indsIce] = np.nan
+                VPice[indsLiq] = np.nan
+                VSice[indsLiq] = np.nan
+                axv[0].plot(VPliq, Planet.z_m[indsHydro]/1e3,
                             color=thisColor, linewidth=Style.LW_sound,
                             linestyle=Style.LS[Planet.Ocean.comp])
-                axv[1].plot(Planet.Seismic.VP_kms[indsIce], Planet.z_m[indsIce]/1e3,
+                axv[1].plot(VPice, Planet.z_m[indsHydro]/1e3,
                             color=thisColor, linewidth=Style.LW_sound,
                             linestyle=Style.LS[Planet.Ocean.comp])
-                axv[2].plot(Planet.Seismic.VS_kms[indsIce], Planet.z_m[indsIce]/1e3,
+                axv[2].plot(VSice, Planet.z_m[indsHydro]/1e3,
                             color=thisColor, linewidth=Style.LW_sound,
                             linestyle=Style.LS[Planet.Ocean.comp])
 
@@ -273,10 +281,9 @@ def PlotCoreTradeoff(PlanetList, Params):
         ax.set_axisbelow(True)
     ax.set_xlabel(FigLbl.RsilLabel)
     ax.set_ylabel(FigLbl.RcoreLabel)
-    ALL_SAME_CMR2 = np.all([Planet.Bulk.Cmeasured == PlanetList[0].Bulk.Cmeasured for Planet in PlanetList]) \
-                and np.all([Planet.Bulk.Cuncertainty == PlanetList[0].Bulk.Cuncertainty for Planet in PlanetList])
+    ALL_SAME_CMR2 = np.all([Planet.CMR2str == PlanetList[0].CMR2str for Planet in PlanetList])
     if ALL_SAME_CMR2:
-        CMR2str = f', $C/MR^2 = {PlanetList[0].Bulk.Cmeasured}\pm{PlanetList[0].Bulk.Cuncertainty}$'
+        CMR2str = f', $C/MR^2 = {PlanetList[0].CMR2str}$'
     else:
         CMR2str = ''
     if Params.ALL_ONE_BODY:
@@ -285,7 +292,6 @@ def PlotCoreTradeoff(PlanetList, Params):
         title = FigLbl.coreCompareTitle + CMR2str
     fig.suptitle(title)
 
-
     for Planet in PlanetList:
         if Planet.Do.Fe_CORE:
             if ALL_SAME_CMR2:
@@ -317,10 +323,9 @@ def PlotSilTradeoff(PlanetList, Params):
 
     ax.set_xlabel(FigLbl.RsilLabel)
     ax.set_ylabel(FigLbl.rhoSilLabel)
-    ALL_SAME_CMR2 = np.all([Planet.Bulk.Cmeasured == PlanetList[0].Bulk.Cmeasured for Planet in PlanetList]) \
-                    and np.all([Planet.Bulk.Cuncertainty == PlanetList[0].Bulk.Cuncertainty for Planet in PlanetList])
+    ALL_SAME_CMR2 = np.all([Planet.CMR2str == PlanetList[0].CMR2str for Planet in PlanetList])
     if ALL_SAME_CMR2:
-        CMR2str = f', $C/MR^2 = {PlanetList[0].Bulk.Cmeasured}\pm{PlanetList[0].Bulk.Cuncertainty}$'
+        CMR2str = f', $C/MR^2 = {PlanetList[0].CMR2str}$'
     else:
         CMR2str = ''
     if Params.ALL_ONE_BODY:
