@@ -103,6 +103,19 @@ class OceanEOSStruct:
                     log.warning(f'Both P and T inputs have length {np.size(P_MPa)}, but they are organized to be ' +
                                  'used as a grid. This will cause an error in SeaFreeze. P list will be adjusted slightly.')
                     P_MPa = np.linspace(P_MPa[0], P_MPa[-1], np.size(P_MPa)-1)
+                # Set extrapolation boundaries to limits defined in SeaFreeze
+                self.Pmax = np.minimum(self.Pmax, 2300)
+                self.Tmin = np.maximum(self.Tmin, 200)
+                self.Tmax = np.minimum(self.Tmax, 355)
+                if np.max(P_MPa) > self.Pmax:
+                    log.warning('Input Pmax greater than SeaFreeze limit for Pure H2O. Resetting to SF max.')
+                    P_MPa = np.linspace(np.min(P_MPa), self.Pmax, np.size(P_MPa))
+                if np.min(T_K) > self.Tmin:
+                    log.warning('Input Tmin less than SeaFreeze limit for Pure H2O. Resetting to SF min.')
+                    T_K = np.linspace(self.Tmin, np.max(T_K), np.size(T_K))
+                if np.max(T_K) > self.Tmax:
+                    log.warning('Input Tmax greater than SeaFreeze limit for Pure H2O. Resetting to SF max.')
+                    T_K = np.linspace(np.min(T_K), self.Tmax, np.size(T_K))
                 PTgrid = np.array([P_MPa, T_K], dtype=object)
                 seaOut = SeaFreeze(PTgrid, 'water1')
                 rho_kgm3 = seaOut.rho
@@ -122,7 +135,7 @@ class OceanEOSStruct:
                 else:
                     self.fn_phase = SFphase()
 
-                self.ufn_Seismic = H2OSeismic(compstr, self.w_ppt, self.EXTRAP)
+                self.ufn_Seismic = H2OSeismic(compstr, P_MPa, T_K, seaOut, self.w_ppt, self.EXTRAP)
                 self.ufn_sigma_Sm = H2Osigma_Sm()
             elif compstr == 'Seawater':
                 self.type = 'GSW'
@@ -285,7 +298,7 @@ class IceEOSStruct:
                 rho_kgm3 = iceOut.rho
                 Cp_JkgK = iceOut.Cp
                 alpha_pK = iceOut.alpha
-                kTherm_WmK = np.array([kThermIsothermalAnderssonIbari2005(P_MPa, PhaseInv(phaseStr)) for _ in T_K]).T
+                kTherm_WmK = np.array([kThermIsothermalAnderssonInaba2005(P_MPa, PhaseInv(phaseStr)) for _ in T_K]).T
                 self.ufn_Seismic = IceSeismic(phaseStr, self.EXTRAP)
                 self.fn_phase = returnVal(self.phaseID)
 
@@ -404,6 +417,11 @@ def CheckIfEOSLoaded(EOSlabel, P_MPa, T_K, FORCE_NEW=False):
                 if deltaT == 0: deltaT = 0.01
                 nPs = int((maxPmax - minPmin) / deltaP)
                 nTs = int((maxTmax - minTmin) / deltaT)
+                # Ensure we don't have too few points that we error later
+                if nPs < 5:
+                    nPs = 5
+                if nTs < 5:
+                    nTs = 5
                 outP_MPa = np.linspace(minPmin, maxPmax, nPs)
                 outT_K = np.linspace(minTmin, maxTmax, nTs)
                 rangeLabel = f'{np.min(outP_MPa):.2f},{np.max(outP_MPa):.2f},{deltaP:.2e},' + \
@@ -451,17 +469,16 @@ class SFphase:
 
 class H2OSeismic:
     """ Creates a function call for returning seismic properties of depth profile for pure water. """
-    def __init__(self, compstr, wOcean_ppt, EXTRAP):
+    def __init__(self, compstr, P_MPa, T_K, seaOut, wOcean_ppt, EXTRAP):
         self.compstr = compstr
         self.w_ppt = wOcean_ppt
         self.EXTRAP = EXTRAP
 
+        self.ufn_VP_kms = RectBivariateSpline(P_MPa, T_K, seaOut.vel * 1e-3)
+        self.ufn_KS_GPa = RectBivariateSpline(P_MPa, T_K, seaOut.Ks * 1e-3)
+
     def __call__(self, P_MPa, T_K):
-        if not self.EXTRAP:
-            # Set extrapolation boundaries to limits defined in SeaFreeze
-            P_MPa, T_K = ResetNearestExtrap(P_MPa, T_K, 0, 2300, 200, 355)
-        seaOut = SeaFreeze(sfPTpairs(P_MPa, T_K), 'water1')
-        return seaOut.vel * 1e-3, seaOut.Ks * 1e-3
+        return self.ufn_VP_kms(P_MPa, T_K, grid=False), self.ufn_KS_GPa(P_MPa, T_K, grid=False)
 
 
 class H2Osigma_Sm:
@@ -675,9 +692,10 @@ def GetPhaseIndices(phase):
                indsSilV, indsSilVI, indsFe
 
 
-def kThermIsobaricAnderssonIbari2005(T_K, phase):
+def kThermIsobaricAnderssonInaba2005(T_K, phase):
     """ Calculate thermal conductivity of ice at a fixed pressure according to
-        Andersson and Ibari (2005) as a function of temperature.
+        Andersson and Inaba (2005) as a function of temperature.
+        See https://doi.org/10.1039/B500373C.
         Range of validity is as follows:
         Phase:  P (MPa):    T range (K):
         Ih      0.1         40-180*
@@ -685,7 +703,7 @@ def kThermIsobaricAnderssonIbari2005(T_K, phase):
         III     240         180-250
         V       530         240-270
         VI      1000        135-250
-        *Andersson and Ibari give an alternate equation that accounts for the range 180-273 K
+        *Andersson and Inaba give an alternate equation that accounts for the range 180-273 K
         for ice Ih at 0.1 MPa, but as this was not included in the Matlab version, it's
         skipped here too. This implementation does not apply at the relevant T and P values
         for icy moon shells except at specific points, so a more versatile and accurate
@@ -706,9 +724,10 @@ def kThermIsobaricAnderssonIbari2005(T_K, phase):
     return kTherm_WmK
 
 
-def kThermIsothermalAnderssonIbari2005(P_MPa, phase):
+def kThermIsothermalAnderssonInaba2005(P_MPa, phase):
     """ Calculate thermal conductivity of ice at a fixed temperature according to
-        Andersson and Ibari (2005) as a function of pressure.
+        Andersson and Inaba (2005) as a function of pressure.
+        See https://doi.org/10.1039/B500373C.
         Range of validity is as follows:
         Phase:  P range (GPa):  T (K):
         Ih      0-0.5           130
