@@ -237,20 +237,11 @@ def IceLayers(Planet, Params):
         else:
             if Planet.Do.NO_ICE_CONVECTION:
                 log.debug('NO_ICE_CONVECTION is True -- skipping ice I convection calculations.')
-                Planet.RaConvect = np.nan
-                Planet.RaCrit = np.nan
-                Planet.Tconv_K = np.nan
-                Planet.etaConv_Pas = np.nan
-            else:
-                Pbot_MPa = np.arange(Planet.PfreezeLower_MPa, Planet.PfreezeUpper_MPa, Planet.PfreezeRes_MPa)
-                Tbot_K = np.arange(Planet.T_K[Planet.Steps.nIceI], np.maximum(273, Planet.T_K[Planet.Steps.nIceI]+20), 0.5)
-                iceImeltEOS = GetOceanEOS('PureH2O', 0.0, Pbot_MPa, Tbot_K, None,
-                                          phaseType=Planet.Ocean.phaseType, FORCE_NEW=True)
-                Planet.Tconv_K, Planet.etaConv_Pas, _, _, _, _, Planet.RaConvect, Planet.RaCrit \
-                    = ConvectionDeschampsSotin2001(Planet.T_K[0], Planet.r_m[0], Planet.kTherm_WmK[0],
-                                                   Planet.T_K[Planet.Steps.nIceI], Planet.z_m[Planet.Steps.nIceI],
-                                                   Planet.g_ms2[0], np.mean([Planet.P_MPa[Planet.Steps.nIceI], Planet.P_MPa[0]]),
-                                                   iceImeltEOS, Planet.Ocean.surfIceEOS['Ih'], 1, Planet.Do.EQUIL_Q)
+            Planet.RaConvect = np.nan
+            Planet.RaCrit = np.nan
+            Planet.Tconv_K = np.nan
+            Planet.etaConv_Pas = np.nan
+            
             Planet.eLid_m = Planet.z_m[Planet.Steps.nSurfIce]
             Planet.Dconv_m = 0.0
             Planet.deltaTBL_m = 0.0
@@ -439,7 +430,7 @@ def OceanLayers(Planet, Params):
             TMelosh_K = TOcean_K[0] + 0
             deltaPtop = 0
             zMelosh = 0
-            while alphaMelosh_pK < 0:
+            while alphaMelosh_pK < 0 and Planet.phase[Planet.Steps.nSurfIce+i] == 0:
                 dz = deltaPMelosh*1e6 / gMelosh_ms2 / rhoMelosh_kgm3
                 zMelosh += dz
                 deltaPtop += deltaPMelosh
@@ -803,7 +794,7 @@ def CalcMoIConstantRho(Planet, Params):
     VsilSphere_m3 = 4/3*np.pi * Planet.r_m[Planet.Steps.iSilStart:]**3
 
     if Planet.Do.Fe_CORE:
-        # Find core bulk density based on assumed sulfide content (Eq X of Styczinski et al., 2022)
+        # Find core bulk density based on assumed sulfide content
         rhoCore_kgm3 = Planet.Core.rhoFeS_kgm3 * Planet.Core.rhoFe_kgm3 \
             * (Planet.Core.xFeS * Constants.mFeS_gmol + (1 - Planet.Core.xFeS) * Constants.mFe_gmol ) \
             / (Planet.Core.xFeS * Constants.mFeS_gmol * Planet.Core.rhoFe_kgm3 + (1 - Planet.Core.xFeS) * Constants.mFe_gmol * Planet.Core.rhoFeS_kgm3)
@@ -851,8 +842,8 @@ def CalcMoIConstantRho(Planet, Params):
     CMR2 = C_kgm2 / MR2_kgm2
 
     CMR2inds = [i[0] for i, valCMR2 in np.ndenumerate(CMR2)
-                 if valCMR2 > Planet.Bulk.Cmeasured - Planet.Bulk.Cuncertainty
-                and valCMR2 < Planet.Bulk.Cmeasured + Planet.Bulk.Cuncertainty]
+                 if valCMR2 > Planet.Bulk.Cmeasured - Planet.Bulk.CuncertaintyLower
+                and valCMR2 < Planet.Bulk.Cmeasured + Planet.Bulk.CuncertaintyUpper]
 
     if len(CMR2inds) == 0:
         if Planet.Do.NO_H2O:
@@ -860,7 +851,7 @@ def CalcMoIConstantRho(Planet, Params):
         else:
             suggestion = '\nTry adjusting properties of silicates and core to get C/MR^2 values in range. ' + \
                          'Increasing PHydroMax_MPa can also lower C/MR^2 values.'
-        msg = f'No MoI found matching C/MR^2 = {Planet.Bulk.Cmeasured:.3f}±{Planet.Bulk.Cuncertainty:.3f}. ' + \
+        msg = f'No MoI found matching C/MR^2 = {Planet.Bulk.Cmeasured:.3f}+{Planet.Bulk.CuncertaintyUpper:.3f}-{Planet.Bulk.CuncertaintyLower}. ' + \
                   f'Min: {np.min(CMR2[CMR2>0]):.3f}, Max: {np.max(CMR2):.3f}.'
         if Params.ALLOW_BROKEN_MODELS:
             fullMsg = msg + suggestion + ' Params.ALLOW_BROKEN_MODELS is True, so calculations will proceed with many values set to nan.'
@@ -886,6 +877,7 @@ def CalcMoIConstantRho(Planet, Params):
         Planet.Steps.nSil = Planet.Steps.nSilMax
         # Use Rset_m to indicate that we have already determined the core size in using SilicateLayers
         Planet.Core.Rset_m = np.nan
+        iCMR2 = 0
         iCMR2inner = 0
         if Planet.Do.NO_H2O:
             Planet.Steps.nHydro = 0
@@ -955,7 +947,7 @@ def CalcMoIConstantRho(Planet, Params):
         Planet.Mtot_kg = np.sum(Planet.MLayer_kg[:iCMR2]) + MtotSil_kg + MtotCore_kg
         if not np.isnan(Planet.CMR2mean):
             log.info(f'Found matching MoI of {Planet.CMR2mean:.4f} ' +
-                     f'(C/MR^2 = {Planet.Bulk.Cmeasured:.4f}±{Planet.Bulk.Cuncertainty:.4f}) for ' +
+                     f'(C/MR^2 = {Planet.CMR2strPrint}) for ' +
                      f'R_sil = {Planet.Sil.Rmean_m / Planet.Bulk.R_m:.2f} R_{Planet.name[0]}, ' +
                      f'R_core = {Planet.Core.Rmean_m / Planet.Bulk.R_m:.2f} R_{Planet.name[0]}, ' +
                      f'rho_sil (found) = {rhoSil_kgm3[iCMR2inner]:.0f} kg/m^3, ' +
@@ -967,7 +959,7 @@ def CalcMoIConstantRho(Planet, Params):
     else:
         if not np.isnan(Planet.CMR2mean):
             log.info(f'Found matching MoI of {Planet.CMR2mean:.4f} ' +
-                     f'(C/MR^2 = {Planet.Bulk.Cmeasured:.4f}±{Planet.Bulk.Cuncertainty:.4f}) for ' +
+                     f'(C/MR^2 = {Planet.CMR2strPrint}) for ' +
                      f'R_sil = {Planet.Sil.Rmean_m / Planet.Bulk.R_m:.2f} R_{Planet.name[0]}, ' +
                      f'R_core = {Planet.Core.Rmean_m / Planet.Bulk.R_m:.2f} R_{Planet.name[0]}, ' +
                      f'rho_sil = {rhoSil_kgm3[iCMR2inner]:.0f} kg/m^3, ' +
@@ -1021,10 +1013,15 @@ def CalcMoIWithEOS(Planet, Params):
         Planet.Sil.fn_Htidal_Wm3 = GetHtidalFunc(Planet.Sil.Htidal_Wm3)  # Placeholder until we implement a self-consistent calc
         Planet.Sil.fn_phi_frac = GetphiCalc(Planet.Sil.phiRockMax_frac, Planet.Sil.EOS.fn_phi_frac, Planet.Sil.phiMin_frac)
         # Propagate the silicate EOS from each hydrosphere layer to the center of the body
-        log.debug(f'Propagating silicate EOS for each possible mantle size...')
+        log.debug(f'Propagating silicate EOS for each possible mantle size ({Planet.Steps.nHydroMax-Planet.Steps.iSilStart} options)...')
         indsSilValid, nProfiles, Psil_MPa, Tsil_K, rSil_m, rhoSil_kgm3, MLayerSil_kg, MAboveSil_kg, gSil_ms2, \
         phiSil_frac, HtidalSil_Wm3, kThermSil_WmK, PsilPore_MPa, rhoSilMatrix_kgm3, rhoSilPore_kgm3, phaseSilPore \
             = SilicateLayers(Planet, Params)
+        if not Planet.Do.VALID and Planet.Steps.iSilStart > 1 and np.size(indsSilValid) != 0:
+            Planet.Steps.iSilStart = 1
+            indsSilValid, nProfiles, Psil_MPa, Tsil_K, rSil_m, rhoSil_kgm3, MLayerSil_kg, MAboveSil_kg, gSil_ms2, \
+            phiSil_frac, HtidalSil_Wm3, kThermSil_WmK, PsilPore_MPa, rhoSilMatrix_kgm3, rhoSilPore_kgm3, phaseSilPore \
+                = SilicateLayers(Planet, Params)
         nSilTooBig = nProfiles - np.size(indsSilValid)
         # Propagate the core EOS from each silicate layer at the max core radius to the center of the body
         nSilFinal, Pcore_MPa, Tcore_K, rCore_m, rhoCore_kgm3, MLayerCore_kg, gCore_ms2, CpCore_JkgK, alphaCore_pK, \
@@ -1051,14 +1048,15 @@ def CalcMoIWithEOS(Planet, Params):
             phiMin_frac = Planet.Sil.phiRockMax_frac - Planet.Sil.phiRockMax_frac / Planet.Sil.phiRangeMult
             phiMax_frac = Planet.Sil.phiRockMax_frac + (1 - Planet.Sil.phiRockMax_frac) / Planet.Sil.phiRangeMult
             multphi_frac = (phiMax_frac/phiMin_frac)**(1/Planet.Steps.nPoros)
-            log.debug(f'Propagating silicate EOS for each possible mantle size and porosity from phiVac = {phiMin_frac:.3f} to {phiMax_frac:.3f}...')
+            log.debug(f'Propagating silicate EOS for each possible mantle size and porosity from phiVac = {phiMin_frac:.3f} to {phiMax_frac:.3f} in {Planet.Steps.nPoros} steps...')
         else:
             # In this case, we will use Sil.HtidalMin_Wm3 and Sil.deltaHtidal_logUnits to get
             # a valid set of profiles.
             HtidalStart_Wm3 = Planet.Sil.HtidalMin_Wm3
             multHtidal_Wm3 = 10**Planet.Sil.deltaHtidal_logUnits
             thisHtidal_Wm3 = 0
-            log.debug(f'Propagating silicate EOS for each possible mantle size and heating from Htidal = {thisHtidal_Wm3:.2e} to {Planet.Sil.HtidalMax_Wm3:.2e} W/m^3...')
+            nHsteps = np.floor(np.log10(Planet.Sil.HtidalMax_Wm3/HtidalStart_Wm3)/Planet.Sil.deltaHtidal_logUnits) + 1
+            log.debug(f'Propagating silicate EOS for each possible mantle size and heating from Htidal = {thisHtidal_Wm3:.2e} to {Planet.Sil.HtidalMax_Wm3:.2e} W/m^3 in {nHsteps} steps...')
             phiMin_frac = Planet.Sil.phiRockMax_frac
             phiMax_frac = phiMin_frac
 
@@ -1150,8 +1148,8 @@ def CalcMoIWithEOS(Planet, Params):
     CMR2 = C_kgm2 / MR2_kgm2
 
     CMR2inds = [i[0] for i, valCMR2 in np.ndenumerate(CMR2)
-                 if valCMR2 > Planet.Bulk.Cmeasured - Planet.Bulk.Cuncertainty
-                and valCMR2 < Planet.Bulk.Cmeasured + Planet.Bulk.Cuncertainty]
+                 if valCMR2 > Planet.Bulk.Cmeasured - Planet.Bulk.CuncertaintyLower
+                and valCMR2 < Planet.Bulk.Cmeasured + Planet.Bulk.CuncertaintyUpper]
 
     if len(CMR2inds) == 0:
         if (np.min(CMR2[iValid]) < Planet.Bulk.Cmeasured) and (np.max(CMR2[iValid]) > Planet.Bulk.Cmeasured):
@@ -1167,7 +1165,7 @@ def CalcMoIWithEOS(Planet, Params):
         else:
             suggestion = '\nTry adjusting properties of silicates and core to get higher C/MR^2 values.'
 
-        msg = f'No MoI found matching C/MR^2 = {Planet.Bulk.Cmeasured:.4f}±{Planet.Bulk.Cuncertainty:.4f}.\n' + \
+        msg = f'No MoI found matching C/MR^2 = {Planet.CMR2strPrint}.\n' + \
               f'Min: {np.min(CMR2[CMR2>0]):.4f}, Max: {np.max(CMR2):.4f}. '
         if Params.ALLOW_BROKEN_MODELS:
             if Params.DO_EXPLOREOGRAM:
@@ -1294,7 +1292,7 @@ def CalcMoIWithEOS(Planet, Params):
 
     if not np.isnan(Planet.CMR2mean):
         log.info(f'Found matching MoI of {Planet.CMR2mean:.4f} ' +
-                 f'(C/MR^2 = {Planet.Bulk.Cmeasured:.4f}±{Planet.Bulk.Cuncertainty:.4f}) for ' +
+                 f'(C/MR^2 = {Planet.CMR2strPrint}) for ' +
                  f'rho_sil = {Planet.Sil.rhoMean_kgm3:.0f} kg/m^3, ' +
                  f'R_sil = {Planet.Sil.Rmean_m / Planet.Bulk.R_m:.3f} R_{Planet.name[0]}, ' +
                  RcoreOrHtidalLine +
